@@ -10,6 +10,7 @@ from aiocometd import Client
 from live_client.events.constants import EVENT_TYPE_DESTROY, EVENT_TYPE_EVENT, EVENT_TYPE_SPAN
 from live_client.connection.rest_input import build_session
 from live_client.utils.network import retry_on_failure, ensure_timeout
+from live_client.utils.processes import get_start_method
 from live_client.utils import logging
 
 
@@ -49,13 +50,14 @@ def start(statement, settings, timeout=None, **kwargs):
     return channels
 
 
-async def read_results(url, channels, output_queue):
+async def read_results(url, channels, output_queue, live_settings):
     setproctitle("live-client: cometd client for channels {}".format(channels))
+    verify_ssl = live_settings.get("verify_ssl", None)
 
     with ensure_timeout(3.05):
         with start_action(action_type="query.read_results", url=url, channels=channels):
             # connect to the server
-            async with Client(url) as client:
+            async with Client(url, ssl=verify_ssl) as client:
                 for channel in channels:
                     logging.debug(f"Subscribing to '{channel}'")
                     await client.subscribe(channel)
@@ -72,13 +74,13 @@ async def read_results(url, channels, output_queue):
                         return
 
 
-def watch(url, channels, output_queue):
+def watch(url, channels, output_queue, settings):
     loop = asyncio.get_event_loop()
-    loop.run_until_complete(read_results(url, channels, output_queue))
+    loop.run_until_complete(read_results(url, channels, output_queue, settings))
 
 
 def run(statement, settings, timeout=None, **kwargs):
-    mp = get_mp_context("fork")
+    mp = get_mp_context(get_start_method())
 
     with start_action(action_type="query.run", statement=statement):
         live_settings = settings["live"]
@@ -91,7 +93,7 @@ def run(statement, settings, timeout=None, **kwargs):
         results_url = f"{live_url}/cometd"
 
         events_queue = mp.Queue()
-        process = mp.Process(target=watch, args=(results_url, channels, events_queue))
+        process = mp.Process(target=watch, args=(results_url, channels, events_queue, settings))
         process.start()
 
     return process, events_queue
